==> xcircuit-3.2.21.tar.bz2: xcircuit-3.2.21/lib/tcl/resource.tcl <==
#--------------------------------
# XCircuit Resource setup for TCL
#--------------------------------

option add *xcircuit.width 1000
option add *xcircuit.height 800
option add *xcircuit.background red

option add *xcircuit*activeBackground brown4
option add *xcircuit*foreground brown4
option add *xcircuit*activeForeground beige
option add *xcircuit*borderwidth 0
option add *xcircuit*font -*-times-bold-r-normal--14-*

option add *xcircuit.menubar.filebutton*background beige
option add *xcircuit.menubar.editbutton*background beige
option add *xcircuit.menubar.textbutton*background beige
option add *xcircuit.menubar.optionsbutton*background beige
option add *xcircuit.menubar.windowbutton*background beige
option add *xcircuit.menubar.netlistbutton*background beige

option add *filelist*activeBackground brown4
option add *filelist*foreground brown4
option add *filelist*activeForeground beige
option add *filelist*borderwidth 0
option add *filelist*font -*-times-bold-r-normal--14-*
option add *filelist*txt*font -*-courier-bold-r-normal--14-*

option add *output*activeBackground brown4
option add *output*foreground brown4
option add *output*activeForeground beige
option add *output*borderwidth 0
option add *output*font -*-times-bold-r-normal--14-*
option add *output*txt*font -*-courier-bold-r-normal--14-*

option add *output.textent.butp.psmenu*background beige
option add *output.textent.txtf.sizb.sizemenu*background beige
option add *output.textent.buto.orientmenu*background beige

option add *help*activeBackground brown4
option add *help*foreground brown4
option add *help*activeForeground beige
option add *help*borderwidth 0
option add *help*font -*-times-bold-r-normal--14-*
option add *help*txt*font -*-times-courier-r-normal--14-*

option add *dialog*activeBackground brown4
option add *dialog*foreground brown4
option add *dialog*activeForeground beige
option add *dialog*borderwidth 0
option add *dialog*font -*-times-bold-r-normal--14-*
option add *dialog*txt*font -*-courier-bold-r-normal--14-*

# End of Resource configuration file.

==> xcircuit-3.6.8.tar.bz2: xcircuit-3.6.8/lib/tcl/resource.tcl <==
#--------------------------------
# XCircuit Resource setup for TCL
#--------------------------------

option add *xcircuit.width 1200
option add *xcircuit.height 910
option add *xcircuit*activeBackground brown4
option add *xcircuit*foreground brown4
option add *xcircuit*activeForeground beige
option add *xcircuit*borderwidth 0
option add *xcircuit*font -*-times-bold-r-normal--14-*

option add *xcircuit1.width 900
option add *xcircuit1.height 700
option add *xcircuit1*activeBackground brown4
option add *xcircuit1*foreground brown4
option add *xcircuit1*activeForeground beige
option add *xcircuit1*borderwidth 0
option add *xcircuit1*font -*-times-bold-r-normal--14-*

option add *xcircuit2.width 700
option add *xcircuit2.height 500
option add *xcircuit2*activeBackground brown4
option add *xcircuit2*foreground brown4
option add *xcircuit2*activeForeground beige
option add *xcircuit2*borderwidth 0
option add *xcircuit2*font -*-times-bold-r-normal--14-*

option add *menubar.filebutton*background beige
option add *menubar.editbutton*background beige
option add *menubar.textbutton*background beige
option add *menubar.optionsbutton*background beige
option add *menubar.windowbutton*background beige
option add *menubar.netlistbutton*background beige
option add *menubar*font -*-times-bold-r-normal--14-*

option add *filelist*activeBackground brown4
option add *filelist*foreground brown4
option add *filelist*activeForeground beige
option add *filelist*borderwidth 0
option add *filelist*font -*-times-bold-r-normal--14-*
option add *filelist*txt*font -*-courier-bold-r-normal--14-*

option add *output*activeBackground brown4
option add *output*foreground brown4
option add *output*activeForeground beige
option add *output*borderwidth 0
option add *output*font -*-times-bold-r-normal--14-*
option add *output*txt*font -*-courier-bold-r-normal--14-*

option add *output.textent.butp.psmenu*background beige
option add *output.textent.txtf.sizb.sizemenu*background beige
option add *output.textent.buto.orientmenu*background beige

option add *help*activeBackground brown4
option add *help*foreground brown4
option add *help*activeForeground beige
option add *help*borderwidth 0
option add *help*font -*-times-bold-r-normal--14-*
option add *help*txt*font -*-times-courier-r-normal--14-*

option add *dialog*activeBackground brown4
option add *dialog*foreground brown4
option add *dialog*activeForeground beige
option add *dialog*borderwidth 0
option add *dialog*font -*-times-bold-r-normal--14-*
option add *dialog*txt*font -*-courier-bold-r-normal--14-*

# End of Resource configuration file.
